# -*- coding: utf-8 -*-
"""
    hexonet.apiconnector
    ~~~~~~~~~~~~~~~~~~~~
    A connector library for the insanely fast HEXONET Backend API.
    :copyright: © 2018 by HEXONET GmbH.
    :license: MIT, see LICENSE for more details.
"""

__version__ = "3.1.4"
name = "hexonet.apiconnector"
